# Package version

This is how the version number for a release is decided.

## Pre 1.0.0

First version starts at 0.1.0, patch number incremented for small releases, minor number incremented for major releases.

## Post 1.0.0

### Development versions

Devolvement versions will be `{version_number}.devx` where x is the dev release in serries.

### Stable releases

Stable releases will start at 1.0.0 and increment the patch number for small releases that don't change any functionality, the minor number for releases that change non-breaking functionality, and the major number will be incremented for releases that contain breaking changes.
